@@ -120,11 +120,17 @@ class GtkNewGameDialog:
             
         # Create model for game time
         defaultTime = glchess.config.get('new_game_dialog/move_time')
+                  # Translators: Time Combo: There is no time limit
         times = [(_('Unlimited'),       0),
+                  # Translators: Time Combo: Game will last one minute
                  (_('One minute'),     60),
+                  # Translators: Time Combo: Game will last five minutes
                  (_('Five minutes'),  300),
+                  # Translators: Time Combo: Game will last 30 minutes
                  (_('30 minutes'),   1800),
+                  # Translators: Time Combo: Game will last one hour
                  (_('One hour'),     3600),
+                  # Translators: Time Combo: User will configure game duration
                  (_('Custom'),         -1)]
         timeModel = gtk.ListStore(str, int)
         activeIter = None
@@ -145,8 +151,11 @@ class GtkNewGameDialog:
         widget.add_attribute(cell, 'text', 0)
 
         model = gtk.ListStore(str, int)
+                  # Translators: Custom Time Combo: User specifying number of seconds for game duration
         units = [(_('seconds'),  1),
+                  # Translators: Custom Time Combo: User specifying number of minutes for game duration
                  (_('minutes'), 60),
+                  # Translators: Custom Time Combo: User specifying number of hours for game duration
                  (_('hours'), 3600)]
         for (name, multiplier) in units:
             iter = model.append()
@@ -164,8 +173,11 @@ class GtkNewGameDialog:
 
         # Create the model for difficulty options
         levelModel = gtk.ListStore(str, str, str)
+                  # Translators: AI Difficulty Combo: AI set to easy difficulty
         levels = [('easy',   _('Easy'),   'weather-few-clouds'),
+                  # Translators: AI Difficulty Combo: AI set to normal diffuculty
                   ('normal', _('Normal'), 'weather-overcast'),
+                  # Translators: AI Difficulty Combo: AI set to hard diffuculty
                   ('hard',   _('Hard'),   'weather-storm')]
         for (key, label, icon) in levels:
             iter = levelModel.append()
@@ -238,6 +250,7 @@ class GtkNewGameDialog:
             
             # Change title for loaded games
             if g.path is not None:
+                # Translators: This is the title of the dialog when continuing a loaded game
                 self.window.set_title(_('Configure loaded game (%i moves)') % len(g.moves))
 
         # Display warning if missing the AIs
@@ -250,7 +263,7 @@ class GtkNewGameDialog:
         self.window.present()
         self.__checking = False
         self.__testReady()
-        
+
     # Private methods
     
     def __setCombo(self, comboName, key):
@@ -296,7 +309,7 @@ class GtkNewGameDialog:
         if self.__customName:
             name = self.__gui.get_widget('game_name_entry').get_text()
             if len(name) == 0:
-                # Next time the something changes generate a name
+                # Next time something changes generate a name
                 self.__customName = False
                 ready = False
 
@@ -304,6 +317,7 @@ class GtkNewGameDialog:
         else:
             whiteName = self.__getComboData(self.__gui.get_widget('white_type_combo'), 2)
             blackName = self.__getComboData(self.__gui.get_widget('black_type_combo'), 2)
+            # Translators: Default name for a new game. %(white) and %(black) are substituted for the names of the white and black players.
             format = _('%(white)s versus %(black)s')
             self.__gui.get_widget('game_name_entry').set_text(format % {'white': whiteName, 'black': blackName})
 
@@ -327,12 +341,14 @@ class GtkNewGameDialog:
         # Get the players
         game.white.type  = self.__getComboData(self.__gui.get_widget('white_type_combo'), 0)
         if game.white.type == '':
+            # Translators: Default name for the white player
             game.white.name = _('White')
         else:
             game.white.name = self.__getComboData(self.__gui.get_widget('white_type_combo'), 2)
         game.white.level = self.__getComboData(self.__gui.get_widget('white_difficulty_combo'), 0)
         game.black.type  = self.__getComboData(self.__gui.get_widget('black_type_combo'), 0)
         if game.black.type == '':
+            # Translators: Default name for the black player
             game.black.name = _('Black')
         else:
             game.black.name = self.__getComboData(self.__gui.get_widget('black_type_combo'), 2)
@@ -384,6 +400,8 @@ class GtkNewGameDialog:
         if responseId == gtk.RESPONSE_OK:
             self.__startGame()
         dialog.destroy()
+        if self.__mainUI.newGameDialog is self:
+            self.__mainUI.newGameDialog = None
 
 class GtkLoadGameDialog:
     """
@@ -440,6 +458,7 @@ class GtkLoadGameDialog:
 
             fileName = self.__gui.get_widget('filechooserwidget').get_filename()
             if fileName is None:
+                # Translators: Message displayed in load game dialog when no file is selected
                 error = _('Please select a file to load')
             else:
                 error = self.__mainUI.feedback.loadGame(fileName, responseId == gtk.RESPONSE_YES)
@@ -447,11 +466,14 @@ class GtkLoadGameDialog:
             if error is not None:
                 self.firstExpose = True
                 self.__gui.get_widget('error_box').show()
+                # Translators: Title of error box when unable to load game
                 self.__gui.get_widget('error_title_label').set_markup('<big><b>%s</b></big>' % _('Unabled to load game'))
                 self.__gui.get_widget('error_description_label').set_markup('<i>%s</i>' % error)
                 return
 
         dialog.destroy()
+        if self.__mainUI.loadGameDialog is self:
+            self.__mainUI.loadGameDialog = None
         
 class GtkSaveGameDialog:
     """
@@ -514,6 +536,7 @@ class GtkSaveGameDialog:
             # Append .pgn to the end if not provided
             fname = chooser.get_filename()
             if fname is None:
+                # Translators: Save Game Dialog: Error displayed when no file name entered
                 self.__setError(_('Please enter a file name'), '')
                 return
             if fname[-4:].lower() != '.pgn':
@@ -526,6 +549,7 @@ class GtkSaveGameDialog:
 
             error = self.__mainUI._saveView(self.__view, fname)
             if error is not None:
+                # Translators: Save Game Dialog: Error title when unable to save game
                 self.__setError(_('Unabled to save game'), error)
                 return
         else:
@@ -551,20 +575,27 @@ class GtkPreferencesDialog:
         moveModel = gtk.ListStore(str, str)
         widget = self.__gui.get_widget('move_format_combo')
         widget.set_model(moveModel)
+                        # Translators: Move Format Combo: Moves shown in human descriptive notation
         move_formats = [('human', _('Human')),
+                        # Translators: Move Format Combo: Moves shown in long algebraic notation (LAN)
                         ('lan', _('Long Algebraic')),
+                        # Translators: Move Format Combo: Moves shown in standard algebraic notation (SAN)
                         ('san', _('Standard Algebraic'))]
         for (key, label) in move_formats:
             iter = moveModel.append()
             moveModel.set(iter, 0, label, 1, key)
 
-        # Make modelfor board orientation
+        # Make model for board orientation
         boardModel = gtk.ListStore(str, str)
         widget = self.__gui.get_widget('board_combo')
         widget.set_model(boardModel)
+                     # Translators: Board Side Combo: Camera will face white player's side
         view_list = [('white', _('White Side')),
+                     # Translators: Board Side Combo: Camera will face black player's side
                      ('black', _('Black Side')),
+                     # Translators: Board Side Combo: Camera will face human player's side
                      ('human', _('Human Side')),
+                     # Translators: Board Side Combo: Camera will face current player's side
                      ('current', _('Current Player'))]
         for (key, label) in view_list:
             iter = boardModel.append()
@@ -574,9 +605,13 @@ class GtkPreferencesDialog:
         promotionModel = gtk.ListStore(str, str)
         widget = self.__gui.get_widget('promotion_type_combo')
         widget.set_model(promotionModel)
+                          # Translators: Promotion Combo: Promote to a queen
         promotion_list = [('queen', _('Queen')),
+                          # Translators: Promotion Combo: Promote to a knight
                           ('knight', _('Knight')),
+                          # Translators: Promotion Combo: Promote to a rook
                           ('rook', _('Rook')),
+                          # Translators: Promotion Combo: Promote to a bishop
                           ('bishop', _('Bishop'))]
         for (key, label) in promotion_list:
             iter = promotionModel.append()
